==> haskell-pointed-5.0.5-46-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-pointed.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 pointed
version:              5.0.5
visibility:           public
id:                   pointed-5.0.5-4Nfvrro6a07CEcUEtJOwpO
key:                  pointed-5.0.5-4Nfvrro6a07CEcUEtJOwpO
license:              BSD-3-Clause
copyright:            Copyright (C) 2008-2016 Edward A. Kmett
maintainer:           Edward A. Kmett <ekmett@gmail.com>
author:               Edward A. Kmett
stability:            provisional
homepage:             http://github.com/ekmett/pointed/
synopsis:             Pointed and copointed data
description:          Pointed and copointed data.
category:             Data
abi:                  2189723e2969fcdd54fbcaf4adc17724
exposed:              True
exposed-modules:      Data.Copointed Data.Pointed
import-dirs:          /usr/lib/ghc-9.4.8/site-local/pointed-5.0.5
library-dirs:         /usr/lib/ghc-9.4.8/site-local/pointed-5.0.5
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/pointed-5.0.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-pointed
hs-libraries:         HSpointed-5.0.5-4Nfvrro6a07CEcUEtJOwpO
depends:
    base-4.17.2.1 comonad-5.0.9-I51Kpbi3BnaLUdzI5pNpo6 containers-0.6.7
    data-default-class-0.1.2.0-J3yYo85AtrC9KKZSpt62Yc
    hashable-1.4.4.0-Jc2uKL4S7Fl9QLNJZYpfiY
    kan-extensions-5.2.7-JfeWffDqtSLKUGtQLeDshe
    semigroupoids-6.0.1-Jr4qwSJRHF330Efi7HW1er stm-2.5.1.0
    tagged-0.8.9-KMS3sfDasKWItFZcxfaN6C transformers-0.5.6.2
    transformers-compat-0.7.2-F1TSDgHxVH372cWL2D3XnQ
    unordered-containers-0.2.20-L3M6eILO3KM5ipeNJik2xY

haddock-interfaces:   /usr/share/doc/haskell-pointed/html/pointed.haddock
haddock-html:         /usr/share/doc/haskell-pointed/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-pointed-5.0.5-54-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-pointed.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 pointed
version:              5.0.5
visibility:           public
id:                   pointed-5.0.5-5eqiNpqHZYQ1rofyzmI9nl
key:                  pointed-5.0.5-5eqiNpqHZYQ1rofyzmI9nl
license:              BSD-3-Clause
copyright:            Copyright (C) 2008-2016 Edward A. Kmett
maintainer:           Edward A. Kmett <ekmett@gmail.com>
author:               Edward A. Kmett
stability:            provisional
homepage:             http://github.com/ekmett/pointed/
synopsis:             Pointed and copointed data
description:          Pointed and copointed data.
category:             Data
abi:                  4f01f53fc979ed3532601bb9a12f9045
exposed:              True
exposed-modules:      Data.Copointed Data.Pointed
import-dirs:          /usr/lib/ghc-9.4.8/site-local/pointed-5.0.5
library-dirs:         /usr/lib/ghc-9.4.8/site-local/pointed-5.0.5
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/pointed-5.0.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-pointed
hs-libraries:         HSpointed-5.0.5-5eqiNpqHZYQ1rofyzmI9nl
depends:
    base-4.17.2.1 comonad-5.0.9-2mR16rI7MANLneB4n6u64z containers-0.6.7
    data-default-class-0.1.2.0-J3yYo85AtrC9KKZSpt62Yc
    hashable-1.4.4.0-D3M5e9EeJxCJTqzfO7ugwa
    kan-extensions-5.2.7-Hl8B6ZHfM4g955tpLCQmaR
    semigroupoids-6.0.1-JkwKDZ0CHrJBmm8BH5uGyt stm-2.5.1.0
    tagged-0.8.9-KMS3sfDasKWItFZcxfaN6C transformers-0.5.6.2
    transformers-compat-0.7.2-F1TSDgHxVH372cWL2D3XnQ
    unordered-containers-0.2.20-Asw2mvs6LgrELNyeUEam3W

haddock-interfaces:   /usr/share/doc/haskell-pointed/html/pointed.haddock
haddock-html:         /usr/share/doc/haskell-pointed/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
